@@ -29,7 +29,7 @@ from exporter import *
 from document import Document
 from languagemanager import get_language_manager
 
-class Manager(Gtk.VBox, Gtk.Buildable):
+class Manager(Gtk.Dialog, Gtk.Buildable):
         NAME_COLUMN = 0
         SORT_COLUMN = 1
         LANG_COLUMN = 2
@@ -47,9 +47,6 @@ class Manager(Gtk.VBox, Gtk.Buildable):
         def __init__(self):
                 self.snippet = None
                 self._temp_export = None
-                self.snippets_doc = None
-                self.manager = None
-                self.default_size = None
 
                 self.key_press_id = 0
 
@@ -175,7 +172,7 @@ class Manager(Gtk.VBox, Gtk.Buildable):
                 cell.set_property('markup', model.get_value(iter, self.NAME_COLUMN))
 
         def on_tree_view_drag_data_get(self, widget, context, selection_data, info, time):
-                gfile = Gio.File(self._temp_export)
+                gfile = Gio.file_new_for_path(self._temp_export)
                 selection_data.set_uris([gfile.get_uri()])
 
         def on_tree_view_drag_begin(self, widget, context):
@@ -201,7 +198,9 @@ class Manager(Gtk.VBox, Gtk.Buildable):
         def on_tree_view_drag_data_received(self, widget, context, x, y, selection, info, timestamp):
                 uris = selection.get_uris()
 
-                self.import_snippets(uris)
+                files = [Gio.file_new_for_uri(x) for x in uris]
+
+                self.import_snippets(files)
 
         def on_tree_view_drag_motion(self, widget, context, x, y, timestamp):
                 # Return False if we are dragging
@@ -232,10 +231,10 @@ class Manager(Gtk.VBox, Gtk.Buildable):
                 tv = self.tree_view
 
                 # Set it as a drag source for exporting snippets
-                Gtk.drag_source_set(tv, Gdk.ModifierType.BUTTON1_MASK, self.dnd_target_list, Gdk.DragAction.DEFAULT | Gdk.DragAction.COPY)
+                tv.drag_source_set(Gdk.ModifierType.BUTTON1_MASK, self.dnd_target_list, Gdk.DragAction.DEFAULT | Gdk.DragAction.COPY)
 
                 # Set it as a drag destination for importing snippets
-                Gtk.drag_dest_set(tv, Gtk.DestDefaults.HIGHLIGHT | Gtk.DestDefaults.DROP,
+                tv.drag_dest_set(Gtk.DestDefaults.HIGHLIGHT | Gtk.DestDefaults.DROP,
                                  self.dnd_target_list, Gdk.DragAction.DEFAULT | Gdk.DragAction.COPY)
 
                 tv.connect('drag_data_get', self.on_tree_view_drag_data_get)
@@ -310,7 +309,6 @@ class Manager(Gtk.VBox, Gtk.Buildable):
                 if lang:
                         source_view.get_buffer().set_highlight_syntax(True)
                         source_view.get_buffer().set_language(lang)
-                        self.snippets_doc = Document(None, source_view)
 
                 combo = self['combo_drop_targets']
 
@@ -318,7 +316,7 @@ class Manager(Gtk.VBox, Gtk.Buildable):
                 entry.connect('focus-out-event', self.on_entry_drop_targets_focus_out)
                 entry.connect('drag-data-received', self.on_entry_drop_targets_drag_data_received)
 
-                lst = Gtk.drag_dest_get_target_list(entry)
+                lst = entry.drag_dest_get_target_list()
                 lst.add_uri_targets(self.TARGET_URI)
 
         def __getitem__(self, key):
@@ -538,11 +536,11 @@ class Manager(Gtk.VBox, Gtk.Buildable):
                         True, 0.5, 0.5)
 
         def get_language(self, path):
-                if path[0] == 0:
+                if path.get_indices()[0] == 0:
                         return None
                 else:
-                        return self.model.get_value(self.model.get_iter( \
-                                        (path[0],)), self.LANG_COLUMN).get_id()
+                        return self.model.get_value(self.model.get_iter(path),
+                                                    self.LANG_COLUMN).get_id()
 
         def new_snippet(self, properties=None):
                 if not self.language_path:
@@ -578,19 +576,27 @@ class Manager(Gtk.VBox, Gtk.Buildable):
 
         # Callbacks
         def do_destroy(self):
+                Gtk.Dialog.do_destroy(self)
+
+                if not self.model:
+                        return
+
                 # Remove temporary drag export
                 if self._temp_export:
                       shutil.rmtree(os.path.dirname(self._temp_export))
                       self._temp_export = None
 
-                if self.snippets_doc:
-                        self.snippets_doc.stop()
-
-                self.manager = None
                 self.unref_languages()
                 self.snippet = None
                 self.model = None
 
+        def do_response(self, resp):
+                if resp == Gtk.ResponseType.HELP:
+                        Gedit.App.get_default().show_help(self, 'gedit', 'gedit-plugins-snippets')
+                        return
+
+                self.destroy()
+
         def on_cell_editing_started(self, renderer, editable, path):
                 piter = self.model.get_iter(path)
 
@@ -729,12 +735,10 @@ class Manager(Gtk.VBox, Gtk.Buildable):
 
                 return fil
 
-        def import_snippets(self, filenames):
+        def import_snippets(self, files):
                 success = True
 
-                for filename in filenames:
-                        gfile = Gio.File(filename)
-
+                for gfile in files:
                         if not Gedit.utils_location_has_file_scheme(gfile):
                                 continue
 
@@ -760,7 +764,7 @@ class Manager(Gtk.VBox, Gtk.Buildable):
                         dialog.destroy()
                         return
 
-                f = dialog.get_uris()
+                f = dialog.get_files()
                 dialog.destroy()
 
                 self.import_snippets(f)
@@ -944,11 +948,12 @@ class Manager(Gtk.VBox, Gtk.Buildable):
                 parent = self.model.iter_parent(piter)
 
                 Library().remove_snippet(node)
+                idx = path.get_indices()
 
                 if self.model.remove(piter):
                         return piter
-                elif path[-1] != 0:
-                        self.select_iter(self.model.get_iter((path[0], path[1] - 1)))
+                elif idx[-1] != 0:
+                        self.select_iter(self.model.get_iter((idx[0], idx[1] - 1)))
                 else:
                         dummy = self.add_new_snippet_node(parent)
                         self.tree_view.expand_row(self.model.get_path(parent), False)
@@ -973,7 +978,8 @@ class Manager(Gtk.VBox, Gtk.Buildable):
                 # Create tree row references
                 references = []
                 for path in paths:
-                        references.append(Gtk.TreeRowReference(self.model, path))
+                        # FIXME: this should be fixed in pygobject or something
+                        references.append(Gtk.TreeRowReference.new(self.model, path))
 
                 # Remove/revert snippets
                 select = None
@@ -1015,10 +1021,10 @@ class Manager(Gtk.VBox, Gtk.Buildable):
 
                         self.snippet_changed()
                         return True
-                elif Library().valid_accelerator(event.keyval, event.get_state()[1]):
+                elif Library().valid_accelerator(event.keyval, event.get_state()):
                         # New accelerator
                         self.set_accelerator(event.keyval, \
-                                        event.get_state()[1] & Gtk.accelerator_get_default_mod_mask())
+                                        event.get_state() & Gtk.accelerator_get_default_mod_mask())
                         entry.set_text(self.snippet.accelerator_display())
                         self.snippet_changed()
                         self.tree_view.grab_focus()
